@@ -22,6 +22,7 @@ class Info(API):
         spot_meta: Optional[SpotMeta] = None,
     ):
         super().__init__(base_url)
+        self.ws_manager: Optional[WebsocketManager] = None
         if not skip_ws:
             self.ws_manager = WebsocketManager(self.base_url)
             self.ws_manager.start()
@@ -43,6 +44,12 @@ class Info(API):
             if name not in self.name_to_coin:
                 self.name_to_coin[name] = spot_info["name"]
 
+    def disconnect_websocket(self):
+        if self.ws_manager is None:
+            raise RuntimeError("Cannot call disconnect_websocket since skip_ws was used")
+        else:
+            self.ws_manager.stop()
+
     def user_state(self, address: str) -> Any:
         """Retrieve trading details about a user.
 
@@ -493,6 +500,56 @@ class Info(API):
         """
         return self.post("/info", {"type": "userFees", "user": address})
 
+    def user_staking_summary(self, address: str) -> Any:
+        """Retrieve the staking summary associated with a user.
+        POST /info
+        Args:
+            address (str): Onchain address in 42-character hexadecimal format;
+                            e.g. 0x0000000000000000000000000000000000000000.
+        Returns:
+            {
+                delegated: float string,
+                undelegated: float string,
+                totalPendingWithdrawal: float string,
+                nPendingWithdrawals: int
+            }
+        """
+        return self.post("/info", {"type": "delegatorSummary", "user": address})
+
+    def user_staking_delegations(self, address: str) -> Any:
+        """Retrieve the user's staking delegations.
+        POST /info
+        Args:
+            address (str): Onchain address in 42-character hexadecimal format;
+                            e.g. 0x0000000000000000000000000000000000000000.
+        Returns:
+            [
+                {
+                    validator: string,
+                    amount: float string,
+                    lockedUntilTimestamp: int
+                },
+            ]
+        """
+        return self.post("/info", {"type": "delegations", "user": address})
+
+    def user_staking_rewards(self, address: str) -> Any:
+        """Retrieve the historic staking rewards associated with a user.
+        POST /info
+        Args:
+            address (str): Onchain address in 42-character hexadecimal format;
+                            e.g. 0x0000000000000000000000000000000000000000.
+        Returns:
+            [
+                {
+                    time: int,
+                    source: string,
+                    totalAmount: float string
+                },
+            ]
+        """
+        return self.post("/info", {"type": "delegatorRewards", "user": address})
+
     def query_order_by_oid(self, user: str, oid: int) -> Any:
         return self.post("/info", {"type": "orderStatus", "user": user, "oid": oid})
 
