@@ -47,6 +47,7 @@ UserFundingsSubscription = TypedDict("UserFundingsSubscription", {"type": Litera
 UserNonFundingLedgerUpdatesSubscription = TypedDict(
     "UserNonFundingLedgerUpdatesSubscription", {"type": Literal["userNonFundingLedgerUpdates"], "user": str}
 )
+WebData2Subscription = TypedDict("WebData2Subscription", {"type": Literal["webData2"], "user": str})
 # If adding new subscription types that contain coin's don't forget to handle automatically rewrite name to coin in info.subscribe
 Subscription = Union[
     AllMidsSubscription,
@@ -58,6 +59,7 @@ Subscription = Union[
     OrderUpdatesSubscription,
     UserFundingsSubscription,
     UserNonFundingLedgerUpdatesSubscription,
+    WebData2Subscription,
 ]
 
 AllMidsData = TypedDict("AllMidsData", {"mids": Dict[str, str]})
@@ -96,7 +98,11 @@ OtherWsMsg = TypedDict(
     "OtherWsMsg",
     {
         "channel": Union[
-            Literal["candle"], Literal["orderUpdates"], Literal["userFundings"], Literal["userNonFundingLedgerUpdates"]
+            Literal["candle"],
+            Literal["orderUpdates"],
+            Literal["userFundings"],
+            Literal["userNonFundingLedgerUpdates"],
+            Literal["webData2"],
         ],
         "data": Any,
     },
@@ -114,8 +120,16 @@ class Cloid:
         self._validate()
 
     def _validate(self):
-        assert self._raw_cloid[:2] == "0x", "cloid is not a hex string"
-        assert len(self._raw_cloid[2:]) == 32, "cloid is not 16 bytes"
+        if not self._raw_cloid[:2] == "0x":
+            raise TypeError("cloid is not a hex string")
+        if not len(self._raw_cloid[2:]) == 32:
+            raise TypeError("cloid is not 16 bytes")
+
+    def __str__(self):
+        return str(self._raw_cloid)
+
+    def __repr__(self):
+        return str(self._raw_cloid)
 
     @staticmethod
     def from_int(cloid: int) -> Cloid:
