@@ -1,7 +1,6 @@
 import json
 import logging
 import threading
-import time
 from collections import defaultdict
 
 import websocket
@@ -30,6 +29,8 @@ def subscription_to_identifier(subscription: Subscription) -> str:
         return f'userFundings:{subscription["user"].lower()}'
     elif subscription["type"] == "userNonFundingLedgerUpdates":
         return f'userNonFundingLedgerUpdates:{subscription["user"].lower()}'
+    elif subscription["type"] == "webData2":
+        return f'webData2:{subscription["user"].lower()}'
 
 
 def ws_msg_to_identifier(ws_msg: WsMsg) -> Optional[str]:
@@ -57,6 +58,8 @@ def ws_msg_to_identifier(ws_msg: WsMsg) -> Optional[str]:
         return f'userFundings:{ws_msg["data"]["user"].lower()}'
     elif ws_msg["channel"] == "userNonFundingLedgerUpdates":
         return f'userNonFundingLedgerUpdates:{ws_msg["data"]["user"].lower()}'
+    elif ws_msg["channel"] == "webData2":
+        return f'webData2:{ws_msg["data"]["user"].lower()}'
 
 
 class WebsocketManager(threading.Thread):
@@ -69,16 +72,25 @@ class WebsocketManager(threading.Thread):
         ws_url = "ws" + base_url[len("http") :] + "/ws"
         self.ws = websocket.WebSocketApp(ws_url, on_message=self.on_message, on_open=self.on_open)
         self.ping_sender = threading.Thread(target=self.send_ping)
+        self.stop_event = threading.Event()
 
     def run(self):
-        self.ping_sender.start()
         self.ws.run_forever()
+        self.ping_sender.start()
 
     def send_ping(self):
-        while True:
-            time.sleep(50)
+        while not self.stop_event.wait(50):
+            if not self.ws.keep_running:
+                break
             logging.debug("Websocket sending ping")
             self.ws.send(json.dumps({"method": "ping"}))
+        logging.debug("Websocket ping sender stopped")
+
+    def stop(self):
+        self.stop_event.set()
+        self.ws.close()
+        if self.ping_sender.is_alive():
+            self.ping_sender.join()
 
     def on_message(self, _ws, message):
         if message == "Websocket connection established.":
